.. _developer_guide:

===============
Developer guide
===============
Are you interested in contributing to Skchange? This guide will help you get started
with setting up your local development environment, understanding the codebase,
and following best practices for contributions.

Reporting bugs and requesting features
--------------------------------------
We use `GitHub issues <https://github.com/NorskRegnesentral/skchange/issues>`_ to track
bugs and feature requests.

Before opening a new issue, please search the existing issues to see if your
problem or idea has already been reported.

In your bug report, please include as many details as possible.

In your feature request, please describe the behaviour you want and why.
Also provide a code example of before (if applicable) and after the feature is
implemented.

Contributing code
-----------------
The following sections provide detailed instructions on how to contribute code to Skchange effectively.
The guide is divided into three parts, which are intended to be read in sequence.

.. toctree::
    :maxdepth: 1

    setup
    contributing
    code_style

For maintainers
---------------
There is an additional section for maintainers, containing information on how to manage
the project, make releases and so forth.

.. toctree::
    :maxdepth: 1

    for_maintainers


Credits
-------
The guide is heavily inspired by similar guides by Sktime and Polars.
